
/* Generated data (by glib-mkenums) */

#ifndef GDATA_ENUMS_H
#define GDATA_ENUMS_H

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "gdata-service.h" */
GType gdata_service_error_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_DATA_SERVICE_ERROR (gdata_service_error_get_type())
GType gdata_authentication_error_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_DATA_AUTHENTICATION_ERROR (gdata_authentication_error_get_type())
/* enumerations from "gdata-parsable.h" */
GType gdata_parser_error_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_DATA_PARSER_ERROR (gdata_parser_error_get_type())
G_END_DECLS

#endif /* !GDATA_ENUMS_H */

/* Generated data ends here */

